function [s,p,mask] = bseg6(image)
%
%  Takes an image, finds ridges and attempts a good segmentation, finding bands
%
%     function [s,p,mask] = bseg6(image)
%
%
%  On Input :
%
%       image - 2D Gray Level Matrix (image)
%
%  On Output :
%
%       s - Segmented, labeled image
%       p - properties (bprops) of the segments of s
%       mask: overlay of connected segments
%

% blur = gblur(image,1.5,7);
blur = image;
[c1, c2] = cridges6(blur);
l = label(c2);

b = bprops(l,blur);
%stemp = goodseg(b,l,blur);
 stemp = f27(b,l);

s = label(stemp);
p = bprops(s,blur);
p = seglink(p,15);
mask = lnkshow(p,s);

% stemp = f27(p,s);
% s = label(stemp);
% p = bprops(s,blur);
